package cn.gygxzc.cloud.config.controller

import cn.gygxzc.cloud.config.model.CommonConfig
import cn.gygxzc.cloud.config.service.ICommonConfigService
import cn.tonyandmoney.tuonq.core.req.PageReq
import com.baomidou.mybatisplus.core.metadata.IPage
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.web.bind.annotation.*
import reactor.core.publisher.Mono

/**
 * 通用配置信息，
 * 删除采用物理删除，我的理解，这些数据并非说紧要到删除了不可修复的程度。
 * 逻辑删除用在数据紧要，删除后无法进行恢复和还原，或者说还原代价较大的场景
 */
@RestController
@RequestMapping("/v1/config/common")
class CommonConfigController {

    @Autowired
    private lateinit var commonService: ICommonConfigService


    /**
     * 根据条件查询全部配置文件，可看全部
     */
    @GetMapping
    fun searchByCond(pageReq: PageReq, entity: CommonConfig): Mono<IPage<CommonConfig>> {
        return Mono.create {
            it.success(commonService.queryByPage(pageReq, entity))
        }
    }

    /**
     * 给服务或者是前端客户端调用的，并非是应用于个人角色权限
     */
    @GetMapping("/application")
    fun queryApplicationConfig(pageReq: PageReq,
                               @RequestParam("server") isServer: Boolean,
                               @RequestParam("application") application: String): Mono<List<CommonConfig>> {
        return Mono.create { it.success(commonService.queryApplicationConfig(isServer, application)) }
    }

    /**
     * 添加配置信息
     */
    @PostMapping
    fun addConfig(@RequestBody entity: CommonConfig): Mono<Void> {
        return Mono.create {
            commonService.save(entity)
            it.success()
        }
    }


    /**
     * 删除配置信息
     */
    @DeleteMapping("/{id}")
    fun deleteConfig(@PathVariable("id") id: Int): Mono<Void> {
        return Mono.create {
            commonService.removeById(id)
            it.success()
        }
    }

    /**
     * 更新配置信息
     */
    @PutMapping
    fun updateConfig(@RequestBody entity: CommonConfig): Mono<Void> {
        return Mono.create {
            commonService.updateById(entity)
            it.success()
        }
    }

}