package cn.gygxzc.cloud.config.controller

import cn.gygxzc.cloud.config.model.ConfigProperty
import cn.gygxzc.cloud.config.service.IConfigPropService
import cn.tonyandmoney.tuonq.core.req.PageReq
import com.baomidou.mybatisplus.core.metadata.IPage
import io.swagger.annotations.Api
import io.swagger.annotations.ApiOperation
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.web.bind.annotation.*
import reactor.core.publisher.Mono

/**
 * @author tuonina
 * @createTime 2019/4/12
 * 后去新增或者修改配置之后需要通过bus 通知服务，并且修改配置应该需要审核
 * 前期没有这个需求，不需要去做这些东西
 */
@RestController
@Api("管理系统的属性")
@RequestMapping("/v1/property/config")
class PropertyMgrController {

    @Autowired
    private lateinit var propService: IConfigPropService

    @PostMapping
    @ApiOperation("添加系统的属性")
    fun addProp(@RequestBody prop: ConfigProperty) {
        propService.addProp(prop)
    }

    @PutMapping("/{id}")
    @ApiOperation("更新系统配置信息")
    fun updateProps(@RequestBody prop: ConfigProperty,
                    @PathVariable("id") id: Int): Mono<Void> {
        return Mono.create {
            prop.id = id
            propService.updateById(prop)
            it.success()
        }

    }

    @DeleteMapping("/{id}")
    @ApiOperation("删除系统配置信息")
    fun delete(@PathVariable("id") id: Int): Mono<Void> {
        return Mono.create {
            propService.deleteById(id)
            it.success()
        }

    }

    @GetMapping
    @ApiOperation("条件查询系统配置信息")
    fun query(cond: ConfigProperty, pageReq: PageReq): Mono<IPage<ConfigProperty>> {
        return Mono.create {
            it.success(propService.query(cond, pageReq))
        }
    }
}